/*
 * Copyright 2013 Mark Slater
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 *
 * 	http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
 */

package net.sourceforge.xazzle.xhtml;

import org.sourceforge.writexml.Attribute;
import org.sourceforge.writexml.Attributes;
import org.sourceforge.writexml.TagName;

import static java.util.Arrays.asList;
import static org.sourceforge.writexml.Attributes.attributes;
import static org.sourceforge.writexml.TagName.tagName;

public final class CaptionTag extends StandardXhtmlTag<CaptionTag, XhtmlTag> {
    private CaptionTag(final TagName tagName, final Attributes attributes, final Iterable<? extends XhtmlTag> children) {
        super(tagName, attributes, children);
    }

    static CaptionTag captionTag(final BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>... children) {
        return captionTag(asList(children));
    }

    static CaptionTag captionTag(final Iterable<? extends BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>> children) {
        return new CaptionTag(tagName("caption"), attributes(), children);
    }

    @Override
    CaptionTag makeANewOne(final Attribute attribute) {
        return new CaptionTag(tagName, attributes.append(attribute), children);
    }
}
