/*
 * Copyright 2013 Mark Slater
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 *
 * 	http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
 */

package net.sourceforge.xazzle.xhtml;

import org.sourceforge.writexml.Attribute;
import org.sourceforge.writexml.Attributes;
import org.sourceforge.writexml.TagName;

import static java.util.Arrays.asList;
import static net.sourceforge.xazzle.xhtml.CollectionUtils.newList;
import static org.sourceforge.writexml.Attribute.attribute;
import static org.sourceforge.writexml.Attributes.attributes;
import static org.sourceforge.writexml.TagName.tagName;

public final class FormTag extends StandardXhtmlTag<FormTag, XhtmlTag> implements XhtmlTag, BodyElement<MayContainFormTag, TagScope.Block> {

    private FormTag(final TagName tagName, final Attributes attributes, final Iterable<? extends XhtmlTag> children) {
        super(tagName, attributes, children);
    }

    static FormTag formTag(final Action action, final BodyElement<DoesNotContainFormTag, ? extends TagScope.Block>... children) {
        return formTag(action, asList(children));
    }

    static FormTag formTag(final Action action, final Iterable<? extends BodyElement<? extends DoesNotContainFormTag, ? extends TagScope.Block>> children) {
        return createFormTag(action, children);
    }

    private static FormTag createFormTag(final Action action, final Iterable<? extends BodyElement<? extends DoesNotContainFormTag, ? extends TagScope.Block>> optionalTags) {
        return new FormTag(tagName("form"), attributes(attribute("action", action, NAMESPACE)), newList(optionalTags));
    }

    public FormTag withOnReset(final EventHandler onReset) {
        return makeANewOne(attribute("onreset", onReset, NAMESPACE));
    }

    public FormTag withAccept(final Accept accept) {
        return makeANewOne(attribute("accept", accept, NAMESPACE));
    }

    public FormTag withAcceptCharacterSet(final CharacterSet characterSet) {
        return makeANewOne(attribute("accept-charset", characterSet, NAMESPACE));
    }

    public FormTag withMethod(final Method method) {
        return makeANewOne(attribute("method", method, NAMESPACE));
    }

    public FormTag withOnSubmit(final EventHandler onSubmit) {
        return makeANewOne(attribute("onsubmit", onSubmit, NAMESPACE));
    }

    public FormTag withEncodingType(final EncodingType textPlain) {
        return makeANewOne(attribute("enctype", textPlain, NAMESPACE));
    }

    @Override
    FormTag makeANewOne(final Attribute attribute) {
        return new FormTag(tagName, attributes.append(attribute), children);
    }
}
