/*
 * Copyright 2013 Mark Slater
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 *
 * 	http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
 */

package net.sourceforge.xazzle.xhtml;

import org.sourceforge.writexml.Attribute;
import org.sourceforge.writexml.AttributeValue;
import org.sourceforge.writexml.Attributes;
import org.sourceforge.writexml.Namespace;

import static java.util.Arrays.asList;
import static org.sourceforge.writexml.Attribute.attribute;
import static org.sourceforge.writexml.Attributes.attributes;
import static org.sourceforge.writexml.TagName.tagName;

public final class ScriptTag extends BaseXhtmlTag<ScriptTag, XhtmlTag> implements HeadChild, BodyElement<MayContainFormTag, TagScope.InlineExceptAnchor> {

    private static final Attribute DEFER = attribute("defer", new AttributeValue() {
        public String asString() {
            return "defer";
        }
    }, NAMESPACE);
    private static final Attribute PRESERVE_SPACE = attribute("space", new AttributeValue() {
        public String asString() {
            return "preserve";
        }
    }, Namespace.XML);

    static ScriptTag scriptTag(final MimeType mimeType, final TextElement textElement) {
        return new ScriptTag(attributes(attribute("type", mimeType, NAMESPACE)), asList(textElement));
    }

    static ScriptTag scriptTag(final MimeType mimeType) {
        return scriptTag(mimeType, XhtmlText.xhtmlText(" "));
    }

    private ScriptTag(final Attributes attributes, final Iterable<? extends XhtmlTag> children) {
        super(tagName("script"), attributes, children);
    }

    public ScriptTag withCharacterSet(final CharacterSet characterSet) {
        return makeANewOne(attribute("charset", characterSet, NAMESPACE));
    }

    public ScriptTag defer() {
        return makeANewOne(DEFER);
    }

    public ScriptTag withSource(final ScriptSource scriptSource) {
        return makeANewOne(attribute("src", scriptSource, NAMESPACE));
    }

    public ScriptTag preserveSpace() {
        return makeANewOne(PRESERVE_SPACE);
    }

    ScriptTag makeANewOne(final Attribute attribute) {
        return new ScriptTag(attributes.append(attribute), children);
    }
}
