/*
 * Copyright 2013 Mark Slater
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 *
 * 	http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
 */

package net.sourceforge.xazzle.xhtml;

import org.sourceforge.writexml.Attribute;
import org.sourceforge.writexml.Attributes;
import org.sourceforge.writexml.TagName;

import static java.util.Arrays.asList;
import static net.sourceforge.xazzle.xhtml.CollectionUtils.newList;
import static net.sourceforge.xazzle.xhtml.IterableUtils.cons;
import static org.sourceforge.writexml.Attributes.attributes;
import static org.sourceforge.writexml.TagName.tagName;

public final class TableHeaderTag<T extends MayContainFormTag> extends TableContentTag<TableHeaderTag<T>> {

    private TableHeaderTag(final TagName tagName, final Attributes attributes, final Iterable<? extends XhtmlTag> children) {
        super(tagName, attributes, children);
    }

    static <T extends MayContainFormTag> TableHeaderTag<T> tableHeaderTag(final TableRowTag<? extends T> child, final TableRowTag<? extends T>... children) {
        return tableHeaderTag(child, asList(children));
    }

    static <T extends MayContainFormTag> TableHeaderTag<T> tableHeaderTag(final TableRowTag<? extends T> child, final Iterable<TableRowTag<? extends T>> children) {
        return new TableHeaderTag<>(tagName("thead"), attributes(), cons(child, newList(children)));
    }

    @Override
    TableHeaderTag<T> makeANewOne(final Attribute attribute) {
        return new TableHeaderTag<>(tagName, attributes.append(attribute), children);
    }
}
